pub enum AgentRelationshipKind {
Flow,
Delegate,
Handoff,
}Expand description
Control-flow semantics for one portable composition relationship.
Variants
Flow
Deterministic workflow control flows from the source node to the target node.
Delegate
Invoke the target and return its result to the caller.
Handoff
Transfer active control to the target.