pub trait InvocationContext: CallbackContext {
// Required methods
fn agent(&self) -> Arc<dyn Agent>;
fn memory(&self) -> Option<Arc<dyn Memory>>;
fn session(&self) -> &dyn Session;
fn run_config(&self) -> &RunConfig;
fn end_invocation(&self);
fn ended(&self) -> bool;
// Provided methods
fn user_scopes(&self) -> Vec<String> { ... }
fn request_metadata(&self) -> HashMap<String, Value> { ... }
}Required Methods
fn agent(&self) -> Arc<dyn Agent>
fn memory(&self) -> Option<Arc<dyn Memory>>
fn session(&self) -> &dyn Session
fn run_config(&self) -> &RunConfig
fn end_invocation(&self)
fn ended(&self) -> bool
Provided Methods
Sourcefn user_scopes(&self) -> Vec<String>
fn user_scopes(&self) -> Vec<String>
Returns the scopes granted to the current user for this invocation.
When a RequestContext is present (set by the
server’s auth middleware bridge), this returns the scopes from that
context. The default returns an empty vec (no scopes granted).
Sourcefn request_metadata(&self) -> HashMap<String, Value>
fn request_metadata(&self) -> HashMap<String, Value>
Returns the request metadata from the auth middleware bridge, if present.
This provides access to custom key-value pairs extracted from the HTTP
request by the RequestContextExtractor.